@@ -84,34 +84,21 @@ class Mixin(object):
             for job in jobs:
                 key, value = next(iter(job.items()))
                 value = [value]
-                for target in targets:
-                    job_to_run.append(
-                        dict(
-                            verb=key,
-                            execute=value,
-                            target=target,
-                            restrict=restrict,
-                            ignore_cache=ignore_cache,
-                            parent_id=parent_id,
-                            return_raw=return_raw,
-                        )
-                    )
-                if not targets:
-                    job_to_run.append(
-                        dict(
-                            verb=key,
-                            execute=value,
-                            restrict=restrict,
-                            ignore_cache=ignore_cache,
-                            parent_id=parent_id,
-                            return_raw=return_raw,
-                        )
+                job_to_run.append(
+                    dict(
+                        verb=key,
+                        execute=value,
+                        targets=targets,
+                        restrict=restrict,
+                        ignore_cache=ignore_cache,
+                        parent_id=parent_id,
+                        return_raw=return_raw,
                     )
+                )
 
         return_data = list()
         count = 0
         for job in job_to_run:
-            count += 1
             formatted_job = user_exec.format_exec(**job)
             if self.args.finger_print:
                 item = json.loads(formatted_job)
@@ -121,12 +108,14 @@ class Mixin(object):
                 return_data.append(
                     "{count:<5} {verb:<13}"
                     " {execute:<39} {fingerprint:>13}".format(
-                        count=count,
+                        count=count
+                        or "\n{a}\n{b:<5}".format(a="*" * 100, b=0),
                         verb=item["verb"],
                         execute=exec_str,
                         fingerprint=item["task_sha1sum"],
                     ).encode()
                 )
+                count += 1
             else:
                 return_data.append(user_exec.send_data(data=formatted_job))
         return return_data
